program DBCExport;

{$mode Delphi}{$H+}

uses
  {$IFDEF UNIX}{$IFDEF UseCThreads}
  cthreads,
  {$ENDIF}{$ENDIF}
  Classes, SysUtils, CustApp
  { you can add units after this },
  USqlDatabase, UDBC, Variants;

type
  { TDBCExport }
  TDBCExport = class(TCustomApplication)
  protected
    procedure DoRun; override;
  public
    DBC: TDBC;
    Database: TSqlDatabase;
    DBCFileName: string;
    NewDBCFileName: string;
    constructor Create(TheOwner: TComponent); override;
    destructor Destroy; override;
    procedure WriteHelp; virtual;
    procedure ShowDBC;
  end;

{ TDBCExport }

procedure TDBCExport.DoRun;
var
  ErrorMsg: String;
begin
  // Quick check parameters
  //ErrorMsg := CheckOptions('h', 'help');
  //if ErrorMsg <> '' then begin
  //  ShowException(Exception.Create(ErrorMsg));
  //  Halt;
  //end;

  // Parse parameters
  if HasOption('h', 'help') then begin
    WriteHelp;
    Halt;
  end;
  if HasOption('f', 'file') then begin
    DBCFileName := GetOptionValue('f', 'file');
    NewDBCFileName := Copy(DBCFileName, 1, Length(DBCFileName) -
      Length(ExtractFileExt(DBCFileName))) + '-2.dbc';
  end else begin
    WriteLn('Source DBC file not specified.');
    Halt;
  end;
  if HasOption('n', 'newfile') then begin
    NewDBCFileName := GetOptionValue('n', 'newfile');
  end;

  if HasOption('s', 'schema') then begin
    Database.Database := GetOptionValue('s', 'schema');
  end else Database.Database := 'wowpreklad';
  if HasOption('u', 'user') then begin
    Database.UserName := GetOptionValue('u', 'user');
  end else Database.UserName := 'root';
  if HasOption('p', 'password') then begin
    Database.Password := GetOptionValue('p', 'password');
  end else Database.Password := '';
  if HasOption('t', 'host') then begin
    Database.Hostname := GetOptionValue('t', 'host');
  end else Database.Hostname := 'localhost';


  ShowDBC;

  // Stop program loop
  Terminate;
end;

constructor TDBCExport.Create(TheOwner: TComponent);
begin
  inherited Create(TheOwner);
  StopOnException := True;
  Database := TSqlDatabase.Create;;
end;

destructor TDBCExport.Destroy;
begin
  Database.Destroy;
  inherited Destroy;
end;

procedure TDBCExport.WriteHelp;
begin
  WriteLn('Usage: ', ExtractFileName(ExeName), ' [options]');
  WriteLn('  -h --help      Show this help');
  WriteLn('  -u --user      Database user name');
  WriteLn('  -p --password  Database password name');
  WriteLn('  -s --schema    Database schema name');
  WriteLn('  -t --host      Database host name');
  WriteLn('  -f --file      Source DBC file name');
  WriteLn('  -n --newfile   New created DBC file name');
end;

procedure TDBCExport.ShowDBC;
var
  X, Y: Integer;
  Text: string;
begin
  DBC := TDBC.Create;
  with DBC do begin
    if FileExists(DBCFileName) then begin
      LoadFromFile(DBCFileName);
      //LoadColumnStrings(1);
      //LoadColumnStrings(127);
      (*for Y := 0 to Length(Cells) - 1 do begin
        Text := '';
        for X := 0 to Length(Cells[Y]) - 1 do
         if VarIsStr(Cells[Y, X]) then Text := Text + Cells[Y, X] + ', '
          else Text := Text + IntToStr(Cells[Y, X]) + ', ';
        WriteLn(Text);
      end;
      *)
      WriteLn('Save');
      SaveToFile(NewDBCFileName);
    end else WriteLn('File ' + DBCFileName + ' not exists.');
    Free;
  end;
end;

var
  Application: TDBCExport;

{$IFDEF WINDOWS}{$R project1.rc}{$ENDIF}

{$R DBCExport.res}

begin
  Application := TDBCExport.Create(nil);
  Application.Run;
  Application.Free;
end.

